import { defineStore } from 'pinia'
import { AxiosWrapper } from '@/utils/axios-wrapper'
import { get } from 'lodash-es'
const url = '/chat'
const axios = new AxiosWrapper()

export const ChatStore = defineStore('chat', () => {
  const query = async ({ skip = 0, limit = undefined, ...info } = {}) => {
    let cond = {}
    if (skip) cond.skip = skip
    if (limit) cond.limit = limit
    cond = { ...cond, ...info }
    const res = await axios.$get(`${url}`, cond)
    return res
  }
  const chat = async (cond) => {
    const res = await axios.$get(`${url}/chat`, cond)
    return res
  }
  const read = async (cond) => {
    const res = await axios.$get(`${url}/read`, cond)
    return res
  }
  const fetch = async (payload) => {
    const res = await axios.$get(`${url}/${payload}`)
    return res
  }
  const create = async (payload) => {
    const res = await axios.$post(`${url}`, payload)
    return res
  }
  const cancel = async (payload) => {
    const res = await axios.$post(`${url}/cancel`, payload)
    return res
  }
  const update = async (payload) => {
    const id = get(payload, 'id', get(payload, '_id'))
    const res = await axios.$post(`${url}/${id}`, payload)
    return res
  }
  const del = async (payload) => {
    const res = await axios.$delete(`${url}/${payload}`)
    return res
  }
  return {
    query,
    chat,
    read,
    fetch,
    create,
    update,
    cancel,
    del
  }
})
